@@ -1,7 +1,6 @@
-isibib2df<-function(D){
-
+isibib2df <- function(D) {
   # this is a legacy function (for old scripts)
-  DATA=bib2df(D,dbsource="isi")
-  
+  DATA <- bib2df(D, dbsource = "isi")
+
   return(DATA)
 }
